<?php

	/**
	 * Translated by Chih-Hsin Lee [chlee@femh.org.tw]
	 * $Id: chinese-tr.php,v 1.18 2007/04/24 11:43:16 soranzo Exp $
	 *
	 *
	 */

	// Language and character set
	$lang['applang'] = '&#27491;&#39636;&#20013;&#25991;&#65288;big5&#65289;';
	$lang['appcharset'] = 'big5';
	$lang['applocale'] = 'zh_TW';
	$lang['appdbencoding'] = 'EUC_TW';
	$lang['applangdir'] = 'ltr';
	
	// Welcome  
	$lang['strintro'] = '&#27489;&#36814;&#20351;&#29992;phpPgAdmin.';
	$lang['strppahome'] = 'phpPgAdmin&#39318;&#38913;';
	$lang['strpgsqlhome'] = 'PostgreSQL&#39318;&#38913;';
	$lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
	$lang['strlocaldocs'] = 'PostgreSQL &#25991;&#20214; (&#26412;&#27231;)';
	$lang['strreportbug'] = '&#36890;&#22577;&#31243;&#24335;&#33261;&#34802;';
	$lang['strviewfaq'] = '&#24120;&#35211;&#21839;&#33287;&#31572;';
	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/?page=faq';
	
	// Basic strings
	$lang['strlogin'] = '&#30331;&#20837;';
	$lang['strloginfailed'] = '&#30331;&#20837;&#22833;&#25943;';
	$lang['strlogindisallowed'] = '&#20282;&#26381;&#22120;&#25298;&#32085;&#30331;&#20837;';
	$lang['strserver'] = '&#20282;&#26381;&#22120;';
	$lang['strlogout'] = '&#36864;&#20986;';
	$lang['strowner'] = '&#25152;&#23660;&#20154;';
	$lang['straction'] = '&#21151;&#33021;';
	$lang['stractions'] = '&#21151;&#33021;';
	$lang['strname'] = '&#21517;&#23383;';
	$lang['strdefinition'] = '&#23450;&#32681;';
	$lang['strproperties'] = '&#23660;&#24615;';
	$lang['strbrowse'] = '&#28687;&#35261;';
	$lang['strdrop'] = '&#21034;&#38500;';
	$lang['strdropped'] = '&#24050;&#21034;&#38500;';
	$lang['strnull'] = '&#20801;&#35377;&#31354;&#20540;';
	$lang['strnotnull'] = '&#19981;&#20801;&#35377;&#31354;&#20540;';
	$lang['strprev'] = '&lt; &#19978;&#19968;&#27493;';
	$lang['strnext'] = '&#19979;&#19968;&#27493; &gt;';
	$lang['strfirst'] = '&lt;&lt; &#31532;&#19968;&#27493;';
	$lang['strlast'] = '&#26368;&#24460;&#19968;&#27493; &gt;&gt;';
	$lang['strfailed'] = '&#22833;&#25943;';
	$lang['strcreate'] = '&#24314;&#31435;';
	$lang['strcreated'] = '&#24050;&#24314;&#31435;';
	$lang['strcomment'] = '&#35387;&#37323;';
	$lang['strlength'] = '&#38263;&#24230;';
	$lang['strdefault'] = '&#38928;&#35373;&#20540;';
	$lang['stralter'] = '&#20462;&#25913;';
	$lang['strok'] = '&#30906;&#23450;';
	$lang['strcancel'] = '&#21462;&#28040;';
	$lang['strsave'] = '&#20786;&#23384;';
	$lang['strreset'] = '&#37325;&#35373;';
	$lang['strinsert'] = '&#25554;&#20837;';
	$lang['strselect'] = '&#36984;&#21462;';
	$lang['strdelete'] = '&#21034;&#38500;';
	$lang['strupdate'] = '&#26356;&#26032;';
	$lang['strreferences'] = '&#21443;&#32771;';
	$lang['stryes'] = '&#26159;';
	$lang['strno'] = '&#21542;';
	$lang['strtrue'] = '&#30495;';
	$lang['strfalse'] = '&#20551;';
	$lang['stredit'] = '&#20462;&#25913;';
	$lang['strcolumns'] = '&#36039;&#26009;&#34892;';
	$lang['strrows'] = '&#36039;&#26009;&#21015;';
	$lang['strrowsaff'] = '&#36039;&#26009;&#21015;&#21463;&#24433;&#38911;&#12290;';
	$lang['strobjects'] = '&#29289;&#20214;';
	$lang['strexample'] = '&#20363;&#22914;&#65306;';
	$lang['strback'] = '&#36820;&#22238;';
	$lang['strqueryresults'] = '&#26597;&#35426;&#32080;&#26524;';
	$lang['strshow'] = '&#39023;&#31034;';
	$lang['strempty'] = '&#31354;';
	$lang['strlanguage'] = '&#35486;&#35328;';
	$lang['strencoding'] = '&#32232;&#30908;';
	$lang['strvalue'] = '&#20540;';
	$lang['strunique'] = '&#29544;&#19968;&#37749;';
	$lang['strprimary'] = '&#20027;&#32034;&#24341;&#37749;';
	$lang['strexport'] = '&#21295;&#20986;';
	$lang['strimport'] = '&#21295;&#20837;';
	$lang['strsql'] = 'SQL';
	$lang['strgo'] = '&#38283;&#22987;';
	$lang['stradmin'] = '&#31649;&#29702;';
	$lang['strvacuum'] = '&#28165;&#31354;';
	$lang['stranalyze'] = '&#20998;&#26512;';
	$lang['strclusterindex'] = '&#21474;&#38598;';
	$lang['strclustered'] = '&#21474;&#38598;?';
	$lang['strreindex'] = '&#37325;&#24314;&#32034;&#24341;';
	$lang['strrun'] = '&#22519;&#34892;';
	$lang['stradd'] = '&#21152;&#20837;';
	$lang['strevent'] = '&#20107;&#20214;';
	$lang['strwhere'] = 'Where';
	$lang['strinstead'] = 'Do Instead';
	$lang['strwhen'] = '&#30070;';
	$lang['strformat'] = '&#26684;&#24335;';
	$lang['strdata'] = '&#36039;&#26009;';
	$lang['strconfirm'] = '&#30906;&#35469;';
	$lang['strexpression'] = '&#34920;&#31034;&#24335;';
	$lang['strellipsis'] = '...';
	$lang['strexpand'] = '&#23637;&#38283;';
	$lang['strcollapse'] = '&#25722;&#30090;';
	$lang['strexplain'] = '&#38369;&#26126;';
	$lang['strexplainanalyze'] = '&#38369;&#26126;&#20998;&#26512;';
	$lang['strfind'] = '&#23563;&#25214;';
	$lang['stroptions'] = '&#36984;&#38917;';
	$lang['strrefresh'] = '&#37325;&#26032;&#25972;&#29702;';
	$lang['strdownload'] = '&#19979;&#36617;';
	$lang['strdownloadgzipped'] = '&#20197;gzip&#22739;&#32302;&#24460;&#19979;&#36617;';
	$lang['strinfo'] = '&#36039;&#35338;'; 
    $lang['stroids'] = 'OIDs'; 
    $lang['stradvanced'] = '&#36914;&#38542;';
	$lang['strvariables'] = '&#35722;&#25976;';
	$lang['strprocess'] = '&#31243;&#24207;';
	$lang['strprocesses'] = '&#31243;&#24207;';
	$lang['strsetting'] = '&#35373;&#23450;';
	$lang['streditsql'] = '&#32232;&#36655;SQL';
	$lang['strruntime'] = '&#32317;&#20849;&#22519;&#34892;&#26178;&#38291;: %s ms';
	$lang['strpaginate'] = '&#20998;&#38913;&#39023;&#31034;&#32080;&#26524;';
	$lang['struploadscript'] = '&#25110;&#26159;&#19978;&#20659;&#19968;&#20491;SQL&#25351;&#20196;&#27284;:';
	$lang['strstarttime'] = '&#38283;&#22987;&#26178;&#38291;';
	$lang['strfile'] = '&#27284;&#26696;';
	$lang['strfileimported'] = '&#27284;&#26696;&#24050;&#21295;&#20837;&#12290;';

	// Error handling
	$lang['strbadconfig'] = '&#24744;&#30340; config.inc.php &#28961;&#25928;&#12290;&#35531;&#21033;&#29992; config.inc.php-dist &#24314;&#31435;&#24744;&#30340; config.inc.php &#27284;&#12290;';
	$lang['strnotloaded'] = '&#24744;&#30340; PHP &#29872;&#22659;&#26410;&#23433;&#35037;&#24517;&#38656;&#30340;&#36039;&#26009;&#24235;&#25903;&#25588;&#12290;';
	$lang['strbadschema'] = '&#25351;&#23450;&#20102;&#28961;&#25928;&#30340;&#27169;&#24335; (schema)&#12290;';
	$lang['strbadencoding'] = '&#36039;&#26009;&#24235;&#28961;&#27861;&#35373;&#23450;&#29992;&#25142;&#31471;&#30340;&#32232;&#30908;&#26041;&#24335;&#12290;';
	$lang['strsqlerror'] = 'SQL &#37679;&#35492;&#65306;';
	$lang['strinstatement'] = '&#26044;&#38515;&#36848;&#20839;&#65306;';
	$lang['strinvalidparam'] = '&#28961;&#25928;&#30340; script &#35722;&#25976;&#12290;';
	$lang['strnodata'] = '&#25214;&#19981;&#21040;&#20219;&#20309;&#36039;&#26009;&#21015;&#12290;';
	$lang['strnoobjects'] = '&#25214;&#19981;&#21040;&#20219;&#20309;&#29289;&#20214;&#12290;';
	$lang['strrownotunique'] = '&#27492;&#39023;&#26009;&#21015;&#28961;&#29544;&#29305;&#35672;&#21029;&#38917;&#12290;';
	$lang['strnoreportsdb'] = '&#24744;&#23578;&#26410;&#24314;&#26032;&#22577;&#34920;&#36039;&#26009;&#24235;&#65292;&#35531;&#21443;&#38321;INSTALL&#27284;&#35498;&#26126;&#12290;';
	$lang['strnouploads'] = '&#19978;&#20659;&#27284;&#26696;&#21151;&#33021;&#24050;&#20572;&#29992;&#12290;';
	$lang['strimporterror'] = '&#21295;&#20837;&#37679;&#35492;&#12290;';
	$lang['strimporterrorline'] = '&#21295;&#20837;&#37679;&#35492;&#30332;&#29983;&#26044;&#31532; %s &#34892;&#12290;';

	// Tables
	$lang['strtable'] = '&#36039;&#26009;&#34920;';
	$lang['strtables'] = '&#36039;&#26009;&#34920;';
	$lang['strshowalltables'] = '&#39023;&#31034;&#25152;&#26377;&#30340;&#36039;&#26009;&#34920;';
	$lang['strnotables'] = '&#25214;&#19981;&#21040;&#27492;&#36039;&#26009;&#34920;&#12290;';
	$lang['strnotable'] = '&#25214;&#19981;&#21040;&#20219;&#20309;&#36039;&#26009;&#34920;&#12290;';
	$lang['strcreatetable'] = '&#24314;&#31435;&#26032;&#36039;&#26009;&#34920;';
	$lang['strtablename'] = '&#36039;&#26009;&#34920;&#21517;';
	$lang['strtableneedsname'] = '&#24744;&#38656;&#28858;&#24744;&#30340;&#36039;&#26009;&#34920;&#21629;&#21517;&#12290;';
	$lang['strtableneedsfield'] = '&#24744;&#33267;&#23569;&#25033;&#25351;&#23450;&#19968;&#20491;&#27396;&#20301;&#12290;';
	$lang['strtableneedscols'] = '&#36039;&#26009;&#34920;&#38656;&#35201;&#19968;&#23450;&#25976;&#30446;&#30340;&#36039;&#26009;&#34892;&#12290;';
	$lang['strtablecreated'] = '&#25104;&#21151;&#24314;&#31435;&#36039;&#26009;&#34920;&#12290;';
	$lang['strtablecreatedbad'] = '&#24314;&#31435;&#36039;&#26009;&#34920;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strconfdroptable'] = '&#24744;&#30906;&#23450;&#35201;&#21034;&#38500;&#36039;&#26009;&#34920; &quot;%s&quot;?';
	$lang['strtabledropped'] = '&#25104;&#21151;&#21034;&#38500;&#36039;&#26009;&#34920;&#12290;';
	$lang['strtabledroppedbad'] = '&#21034;&#38500;&#36039;&#26009;&#34920;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strconfemptytable'] = '&#24744;&#30906;&#23450;&#35201;&#28165;&#31354;&#36039;&#26009;&#34920; &quot;%s&quot;?';
	$lang['strtableemptied'] = '&#25104;&#21151;&#28165;&#31354;&#36039;&#26009;&#34920;&#12290;';
	$lang['strtableemptiedbad'] = '&#28165;&#31354;&#36039;&#26009;&#34920;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strinsertrow'] = '&#25554;&#20837;&#36039;&#26009;&#34892;';
	$lang['strrowinserted'] = '&#25104;&#21151;&#25554;&#20837;&#36039;&#26009;&#34892;&#12290;';
	$lang['strrowinsertedbad'] = '&#25554;&#20837;&#36039;&#26009;&#34892;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['streditrow'] = '&#20462;&#25913;&#36039;&#26009;&#34892;';
	$lang['strrowupdated'] = '&#25104;&#21151;&#26356;&#26032;&#36039;&#26009;&#34892;&#12290;';
	$lang['strrowupdatedbad'] = '&#26356;&#26032;&#36039;&#26009;&#34892;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strdeleterow'] = '&#21034;&#38500;&#36039;&#26009;&#34892;';
	$lang['strconfdeleterow'] = '&#24744;&#30906;&#23450;&#35201;&#21034;&#38500;&#20123;&#36039;&#26009;&#34892;?';
	$lang['strrowdeleted'] = '&#25104;&#21151;&#21034;&#38500;&#36039;&#26009;&#34892;&#12290;';
	$lang['strrowdeletedbad'] = '&#36039;&#26009;&#34892;&#21034;&#38500;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strsaveandrepeat'] = '&#20786;&#23384;&#20006;&#37325;&#35206;';
	$lang['strfield'] = '&#27396;&#20301;';
	$lang['strfields'] = '&#27396;&#20301;';
	$lang['strnumfields'] = '&#27396;&#20301;&#25976;&#30446;';
	$lang['strfieldneedsname'] = '&#24744;&#38656;&#28858;&#24744;&#30340;&#27396;&#20301;&#21629;&#21517;&#12290;';
	$lang['strselectallfields'] = '&#36984;&#25799;&#25152;&#26377;&#27396;&#20301;';
	$lang['strselectneedscol'] = '&#33267;&#23569;&#25033;&#39023;&#31034;&#19968;&#36039;&#26009;&#21015;&#12290;';
	$lang['strselectunary'] = '&#19981;&#33021;&#28858;&#19968;&#20803;&#36939;&#31639;&#23376;&#25351;&#23450;&#25976;&#20540;&#12290;';
	$lang['straltercolumn'] = '&#20462;&#25913;&#36039;&#26009;&#21015;';
	$lang['strcolumnaltered'] = '&#25104;&#21151;&#20462;&#25913;&#36039;&#26009;&#21015;&#12290;';
	$lang['strcolumnalteredbad'] = '&#20462;&#25913;&#36039;&#26009;&#21015;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strconfdropcolumn'] = '&#24744;&#30906;&#23450;&#35201;&#21034;&#38500;&#36039;&#26009;&#21015; &quot;%s&quot; &#26044;&#36039;&#26009;&#34920; &quot;%s&quot;?';
	$lang['strcolumndropped'] = '&#25104;&#21151;&#21034;&#38500;&#36039;&#26009;&#21015;&#12290;';
	$lang['strcolumndroppedbad'] = '&#21034;&#38500;&#36039;&#26009;&#21015;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['straddcolumn'] = '&#21152;&#20837;&#26032;&#36039;&#26009;&#27396;';
	$lang['strcolumnadded'] = '&#25104;&#21151;&#21152;&#20837;&#36039;&#26009;&#27396;&#12290;';
	$lang['strcolumnaddedbad'] = '&#21152;&#20837;&#36039;&#26009;&#27396;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strcascade'] = 'CASCADE';
	$lang['strtablealtered'] = '&#36039;&#26009;&#34920;&#24050;&#20462;&#25913;&#12290;';
	$lang['strtablealteredbad'] = '&#36039;&#26009;&#34920;&#20462;&#25913;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strdataonly'] = '&#21482;&#39023;&#31034;&#36039;&#26009;'; 
    $lang['strstructureonly'] = '&#21482;&#26377;&#32080;&#27083;'; 
    $lang['strstructureanddata'] = '&#36039;&#26009;&#21644;&#32080;&#27083;'; 
	$lang['strtabbed'] = 'Tabbed';
	$lang['strauto'] = '&#33258;&#21205;';

	// Users
	$lang['struser'] = '&#29992;&#25142;';
	$lang['strusers'] = '&#29992;&#25142;';
	$lang['strusername'] = '&#29992;&#25142;&#21517;';
	$lang['strpassword'] = '&#23494;&#30908;';
	$lang['strsuper'] = '&#36229;&#32026;&#29992;&#25142;?';
	$lang['strcreatedb'] = '&#20801;&#35377;&#24314;&#31435;&#36039;&#26009;&#24235;?';
	$lang['strexpires'] = '&#22833;&#25928;';
	$lang['strsessiondefaults'] = '&#38928;&#35373;Session';
	$lang['strnousers'] = '&#25214;&#19981;&#21040;&#27492;&#29992;&#25142;&#12290;';
	$lang['struserupdated'] = '&#25104;&#21151;&#26356;&#26032;&#29992;&#25142;&#12290;';
	$lang['struserupdatedbad'] = '&#26356;&#26032;&#29992;&#25142;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strshowallusers'] = '&#39023;&#31034;&#25152;&#26377;&#29992;&#25142;';
	$lang['strcreateuser'] = '&#24314;&#31435;&#26032;&#29992;&#25142;';
	$lang['struserneedsname'] = '&#35531;&#28858;&#27492;&#29992;&#25142;&#21629;&#25142;';
	$lang['strusercreated'] = '&#25104;&#21151;&#24314;&#31435;&#26032;&#29992;&#25142;&#12290;';
	$lang['strusercreatedbad'] = '&#24314;&#31435;&#26032;&#29992;&#25142;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strconfdropuser'] = '&#24744;&#30906;&#23450;&#35201;&#21034;&#38500;&#29992;&#25142; &quot;%s&quot;?';
	$lang['struserdropped'] = '&#29992;&#25142;&#24050;&#21034;&#38500;&#12290;';
	$lang['struserdroppedbad'] = '&#21034;&#38500;&#29992;&#25142;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['straccount'] = '&#24115;&#25142;';
	$lang['strchangepassword'] = '&#26356;&#25913;&#23494;&#30908;';
	$lang['strpasswordchanged'] = '&#25104;&#21151;&#26356;&#25913;&#23494;&#30908;&#12290;';
	$lang['strpasswordchangedbad'] = '&#26356;&#25913;&#23494;&#30908;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strpasswordshort'] = '&#23494;&#30908;&#22826;&#30701;&#12290;';
	$lang['strpasswordconfirm'] = '&#25152;&#36664;&#20837;&#30340;&#20841;&#32068;&#23494;&#30908;&#19981;&#21516;&#12290;';
	
	// Groups
	$lang['strgroup'] = '&#32676;&#32068;';
	$lang['strgroups'] = '&#32676;&#32068;';
	$lang['strnogroup'] = '&#25214;&#19981;&#21040;&#27492;&#32676;&#32068;&#12290;';
	$lang['strnogroups'] = '&#25214;&#19981;&#21040;&#20219;&#20309;&#32676;&#32068;&#12290;';
	$lang['strcreategroup'] = '&#24314;&#31435;&#26032;&#32676;&#32068;';
	$lang['strshowallgroups'] = '&#39023;&#31034;&#25152;&#26377;&#32676;&#32068;';
	$lang['strgroupneedsname'] = '&#24744;&#38656;&#28858;&#24744;&#30340;&#32676;&#32068;&#21629;&#21517;&#12290;';
	$lang['strgroupcreated'] = '&#25104;&#21151;&#24314;&#31435;&#32676;&#32068;&#12290;';
	$lang['strgroupcreatedbad'] = '&#32676;&#32068;&#24314;&#31435;&#20316;&#26989;&#22833;&#25943;&#12290;';	
	$lang['strconfdropgroup'] = '&#24744;&#30906;&#23450;&#21034;&#38500;&#32676;&#32068; &quot;%s&quot;?';
	$lang['strgroupdropped'] = '&#25104;&#21151;&#21034;&#38500;&#32676;&#32068;&#12290;';
	$lang['strgroupdroppedbad'] = '&#21034;&#38500;&#32676;&#32068;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strmembers'] = '&#29992;&#25142;';
	$lang['straddmember'] = '&#26032;&#22686;&#29992;&#25142;';
	$lang['strmemberadded'] = '&#24050;&#21152;&#20837;&#29992;&#25142;&#12290;';
	$lang['strmemberaddedbad'] = '&#26032;&#22686;&#29992;&#25142;&#22833;&#25943;&#12290;';
	$lang['strdropmember'] = '&#21034;&#38500;&#29992;&#25142;';
	$lang['strconfdropmember'] = '&#24744;&#30906;&#23450;&#35201;&#21034;&#38500;&#29992;&#25142; &quot;%s&quot; &#24478;&#32676;&#32068; &quot;%s&quot;&#20013;?';
	$lang['strmemberdropped'] = '&#29992;&#25142;&#24050;&#21034;&#38500;&#12290;';
	$lang['strmemberdroppedbad'] = '&#21034;&#38500;&#29992;&#25142;&#20316;&#26989;&#22833;&#25943;&#12290;';
	
	// Privilges
	$lang['strprivilege'] = '&#29305;&#27402;';
	$lang['strprivileges'] = '&#29305;&#27402;';
	$lang['strnoprivileges'] = '&#35442;&#29289;&#20214;&#26377;&#38928;&#35373;&#30340;&#25152;&#23660;&#20837;&#29305;&#27402;&#12290;';
	$lang['strgrant'] = '&#36070;&#20104;';
	$lang['strrevoke'] = '&#25764;&#22238;';
	$lang['strgranted'] = '&#25104;&#21151;&#26356;&#25913;&#29305;&#27402;&#12290;';
	$lang['strgrantfailed'] = '&#26356;&#25913;&#29305;&#27402;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strgrantbad'] = '&#24744;&#25033;&#28858;&#19968;&#21517;&#20351;&#29992;&#32773;&#25110;&#32676;&#32068;&#25351;&#23450;&#33267;&#23569;&#19968;&#20491;&#29305;&#27402;&#12290;';
	$lang['stralterprivs'] = '&#26356;&#25913;&#29305;&#27402;';
	$lang['strgrantor'] = '&#25480;&#27402;&#32773;';
	$lang['strasterisk'] = '*';
	
	// Databases
	$lang['strdatabase'] = '&#36039;&#26009;&#24235;';
	$lang['strdatabases'] = '&#36039;&#26009;&#24235;';
	$lang['strshowalldatabases'] = '&#39023;&#31034;&#25152;&#26377;&#36039;&#26009;&#24235;';
	$lang['strnodatabase'] = '&#25214;&#19981;&#21040;&#27492;&#36039;&#26009;&#24235;&#12290;';
	$lang['strnodatabases'] = '&#25214;&#19981;&#21040;&#20219;&#20309;&#36039;&#26009;&#24235;&#12290;';
	$lang['strcreatedatabase'] = '&#24314;&#31435;&#26032;&#36039;&#26009;&#24235;';
	$lang['strdatabasename'] = '&#36039;&#26009;&#24235;&#21517;';
	$lang['strdatabaseneedsname'] = '&#24744;&#38656;&#28858;&#24744;&#30340;&#36039;&#26009;&#24235;&#21629;&#21517;&#12290;';
	$lang['strdatabasecreated'] = '&#25104;&#21151;&#24314;&#31435;&#36039;&#26009;&#24235;&#12290;';
	$lang['strdatabasecreatedbad'] = '&#24314;&#31435;&#36039;&#26009;&#24235;&#20316;&#26989;&#22833;&#25943;&#12290;';	
	$lang['strconfdropdatabase'] = '&#24744;&#30906;&#23450;&#35201;&#21034;&#38500;&#36039;&#26009;&#24235; &quot;%s&quot;?';
	$lang['strdatabasedropped'] = '&#25104;&#21151;&#21034;&#38500;&#36039;&#26009;&#24235;&#12290;';
	$lang['strdatabasedroppedbad'] = '&#21034;&#38500;&#36039;&#26009;&#24235;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strentersql'] = '&#26044;&#19979;&#26041;&#36664;&#20837;&#25152;&#35201;&#22519;&#34892;&#30340; SQL &#38515;&#36848;&#24335;&#65306;';
	$lang['strsqlexecuted'] = '&#25104;&#21151;&#22519;&#34892; SQL &#12290;';
	$lang['strvacuumgood'] = '&#28165;&#31354;&#20316;&#26989;&#23436;&#25104;&#12290;';
	$lang['strvacuumbad'] = '&#28165;&#31354;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['stranalyzegood'] = '&#20998;&#26512;&#20316;&#26989;&#23436;&#25104;&#12290;';
	$lang['stranalyzebad'] = '&#20998;&#26512;&#20316;&#26989;&#22833;&#25943;.';
	$lang['strreindexgood'] = '&#32034;&#24341;&#37325;&#24314;&#23436;&#25104;&#12290;';
	$lang['strreindexbad'] = '&#32034;&#24341;&#37325;&#24314;&#22833;&#25943;&#12290;';
	$lang['strfull'] = '&#23436;&#25972;';
	$lang['strfreeze'] = '&#20941;&#32080;';
	$lang['strforce'] = '&#24375;&#21046;';
	
	// Views
	$lang['strview'] = '&#35222;&#34920;';
	$lang['strviews'] = '&#35222;&#34920;';
	$lang['strshowallviews'] = '&#39023;&#31034;&#25152;&#26377;&#35222;&#34920;';
	$lang['strnoview'] = '&#25214;&#19981;&#21040;&#27492;&#35222;&#34920;&#12290;';
	$lang['strnoviews'] = '&#25214;&#19981;&#21040;&#20219;&#20309;&#35222;&#34920;&#12290;';
	$lang['strcreateview'] = '&#24314;&#31435;&#26032;&#35222;&#34920;';
	$lang['strviewname'] = '&#35222;&#34920;&#21517;';
	$lang['strviewneedsname'] = '&#24744;&#38656;&#28858;&#24744;&#30340;&#35222;&#34920;&#21629;&#21517;&#12290;';
	$lang['strviewneedsdef'] = '&#24744;&#24517;&#38920;&#23450;&#32681;&#20320;&#30340;&#35222;&#34920;&#12290;';
	$lang['strviewneedsfields'] = '&#35531;&#36984;&#25799;&#35201;&#21152;&#20837;&#35222;&#34920;&#30340;&#36039;&#26009;&#27396;&#12290;';
	$lang['strviewcreated'] = '&#25104;&#21151;&#24314;&#31435;&#26032;&#35222;&#34920;&#12290;';
	$lang['strviewcreatedbad'] = '&#24314;&#31435;&#26032;&#35222;&#34920;&#20316;&#26989;&#22833;&#25943;';
	$lang['strconfdropview'] = '&#24744;&#30906;&#23450;&#35201;&#21034;&#38500;&#35222;&#34920; &quot;%s&quot;?';
	$lang['strviewdropped'] = '&#25104;&#21151;&#21034;&#38500;&#35222;&#34920;&#12290;';
	$lang['strviewdroppedbad'] = '&#21034;&#38500;&#35222;&#34920;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strviewupdated'] = '&#25104;&#21151;&#26356;&#26032;&#35222;&#34920;&#12290;';
	$lang['strviewupdatedbad'] = '&#26356;&#26032;&#35222;&#34920;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strviewlink'] = '&#36899;&#32080;&#32034;&#24341;';
	$lang['strviewconditions'] = '&#38989;&#22806;&#26781;&#20214;';
	$lang['strcreateviewwiz'] = '&#20351;&#29992;&#35222;&#34920;&#31934;&#38728;';

	// Sequences
	$lang['strsequence'] = '&#24207;&#21015;';
	$lang['strsequences'] = '&#24207;&#21015;';
	$lang['strshowallsequences'] = '&#39023;&#31034;&#25152;&#26377;&#24207;&#21015;';
	$lang['strnosequence'] = '&#25214;&#19981;&#21040;&#27492;&#24207;&#21015;&#12290;';
	$lang['strnosequences'] = '&#25214;&#19981;&#21040;&#20219;&#20309;&#24207;&#21015;&#12290;';
	$lang['strcreatesequence'] = '&#24314;&#31435;&#26032;&#24207;&#21015;';
	$lang['strlastvalue'] = '&#32080;&#26463;&#20540;';
	$lang['strincrementby'] = '&#22686;&#37327; (&#21152;/&#28187;) ';	
	$lang['strstartvalue'] = '&#21855;&#22987;&#20540;';
	$lang['strmaxvalue'] = '&#26368;&#22823;&#20540;';
	$lang['strminvalue'] = '&#26368;&#23569;&#20540;';
	$lang['strcachevalue'] = '&#24555;&#21462;&#20540;';
	$lang['strlogcount'] = '&#30331;&#37636;&#25976;&#37327;';
	$lang['striscycled'] = '&#24490;&#29872;?';
	$lang['strsequenceneedsname'] = '&#24744;&#38656;&#28858;&#24744;&#30340;&#24207;&#21015;&#21629;&#21517;&#12290;';
	$lang['strsequencecreated'] = '&#25104;&#21151;&#24314;&#31435;&#26032;&#24207;&#21015;&#12290;';
	$lang['strsequencecreatedbad'] = '&#24314;&#31435;&#26032;&#24207;&#21015;&#20316;&#26989;&#22833;&#25943;&#12290;'; 
	$lang['strconfdropsequence'] = '&#24744;&#30906;&#23450;&#35201;&#21034;&#38500;&#24207;&#21015; &quot;%s&quot;?';
	$lang['strsequencedropped'] = '&#25104;&#21151;&#21034;&#38500;&#24207;&#21015;&#12290;';
	$lang['strsequencedroppedbad'] = '&#21034;&#38500;&#24207;&#21015;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strsequencereset'] = '&#24050;&#37325;&#35373;&#24207;&#21015;&#12290;'; 
    $lang['strsequenceresetbad'] = '&#37325;&#35373;&#24207;&#21015;&#22833;&#25943;&#12290;'; 
    
	// Indexes
	$lang['strindex'] = '&#32034;&#24341;';
	$lang['strindexes'] = '&#32034;&#24341;';
	$lang['strindexname'] = '&#32034;&#24341;&#21517;';
	$lang['strshowallindexes'] = '&#39023;&#31034;&#25152;&#26377;&#30340;&#32034;&#24341;';
	$lang['strnoindex'] = '&#25214;&#19981;&#21040;&#27492;&#32034;&#24341;&#12290;';
	$lang['strnoindexes'] = '&#25214;&#19981;&#21040;&#20219;&#20309;&#32034;&#24341;&#12290;';
	$lang['strcreateindex'] = '&#24314;&#31435;&#26032;&#32034;&#24341;';
	$lang['strtabname'] = '&#27298;&#32034;&#21517;';
	$lang['strcolumnname'] = '&#36039;&#26009;&#21015;&#21517;';
	$lang['strindexneedsname'] = '&#24744;&#38656;&#28858;&#24744;&#30340;&#32034;&#24341;&#21629;&#21517;&#12290;';
	$lang['strindexneedscols'] = '&#32034;&#24341;&#25033;&#26377;&#19968;&#23450;&#25976;&#21839;&#30340;&#36039;&#26009;&#21015;&#12290;';
	$lang['strindexcreated'] = '&#25104;&#21151;&#24314;&#31435;&#26032;&#32034;&#24341;';
	$lang['strindexcreatedbad'] = '&#24314;&#31435;&#32034;&#24341;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strconfdropindex'] = '&#24744;&#30906;&#23450;&#35201;&#21034;&#38500;&#32034;&#24341; &quot;%s&quot;?';
	$lang['strindexdropped'] = '&#25104;&#21151;&#21034;&#38500;&#32034;&#24341;&#12290;';
	$lang['strindexdroppedbad'] = '&#21034;&#38500;&#32034;&#24341;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strkeyname'] = '&#37749;&#21517;';
	$lang['struniquekey'] = '&#29544;&#19968;&#37749;';
	$lang['strprimarykey'] = '&#20027;&#32034;&#24341;&#37749;';
 	$lang['strindextype'] = '&#32034;&#24341;&#39006;&#22411;';
	$lang['strtablecolumnlist'] = '&#36039;&#26009;&#34920;&#25152;&#21547;&#30340;&#36039;&#26009;&#21015;';
	$lang['strindexcolumnlist'] = '&#32034;&#24341;&#25152;&#21547;&#30340;&#36039;&#26009;&#21015;';
    $lang['strconfcluster'] = '&#24744;&#30906;&#23450;&#35201;&#21474;&#38598; &quot;%s&quot;?'; 
    $lang['strclusteredgood'] = '&#21474;&#38598;&#23436;&#25104;&#12290;'; 
    $lang['strclusteredbad'] = '&#21474;&#38598;&#22833;&#25943;&#12290;'; 

	// Rules
	$lang['strrules'] = '&#35215;&#21063;';
	$lang['strrule'] = '&#35215;&#21063;';
	$lang['strshowallrules'] = '&#39023;&#31034;&#25152;&#26377;&#30340;&#35215;&#21063;';
	$lang['strnorule'] = '&#25214;&#19981;&#21040;&#27492;&#35215;&#21063;&#12290;';
	$lang['strnorules'] = '&#25214;&#19981;&#21040;&#20219;&#20309;&#35215;&#21063;&#12290;';
	$lang['strcreaterule'] = '&#24314;&#31435;&#26032;&#35215;&#21063;';
	$lang['strrulename'] = '&#35215;&#21063;&#21517;';
	$lang['strruleneedsname'] = '&#24744;&#38656;&#28858;&#24744;&#30340;&#35215;&#21063;&#21629;&#21517;&#12290;';
	$lang['strrulecreated'] = '&#25104;&#21151;&#24314;&#31435;&#26032;&#35215;&#21063;&#12290;';
	$lang['strrulecreatedbad'] = '&#24314;&#31435;&#26032;&#35215;&#21063;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strconfdroprule'] = '&#24744;&#30906;&#23450;&#35201;&#21034;&#38500; &quot;%s&quot; &#26044; &quot;%s&quot;?';
	$lang['strruledropped'] = '&#25104;&#21151;&#21034;&#38500;&#35215;&#21063;&#12290;';
	$lang['strruledroppedbad'] = '&#21034;&#38500;&#35215;&#21063;&#20316;&#26989;&#22833;&#25943;&#12290;';

	// Constraints
	$lang['strconstraints'] = '&#32004;&#26463;';
	$lang['strshowallconstraints'] = '&#39023;&#31034;&#25152;&#26377;&#30340;&#32004;&#26463;';
	$lang['strnoconstraints'] = '&#25214;&#19981;&#21040;&#27492;&#32004;&#26463;&#12290;';
	$lang['strcreateconstraint'] = '&#24314;&#31435;&#26032;&#32004;&#26463;';
	$lang['strconstraintcreated'] = '&#25104;&#21151;&#24314;&#31435;&#26032;&#32004;&#26463;&#12290;';
	$lang['strconstraintcreatedbad'] = '&#26032;&#24314;&#32004;&#26463;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strconfdropconstraint'] = '&#24744;&#30906;&#23450;&#35201;&#21034;&#38500;&#32004;&#26463; &quot;%s&quot; &#26044; &quot;%s&quot;?';
	$lang['strconstraintdropped'] = '&#25104;&#21151;&#21034;&#38500;&#32004;&#26463;&#12290;';
	$lang['strconstraintdroppedbad'] = '&#21034;&#38500;&#32004;&#26463;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['straddcheck'] = '&#21152;&#20837;&#26032;&#26597;&#39511; (check)';
	$lang['strcheckneedsdefinition'] = '&#24744;&#38656;&#23450;&#32681;&#24744;&#30340;&#26597;&#39511; (check)&#12290;';
	$lang['strcheckadded'] = '&#25104;&#21151;&#21152;&#20837;&#26032;&#26597;&#39511; (check)&#12290;';
	$lang['strcheckaddedbad'] = '&#21152;&#20837;&#26032;&#26597;&#39511; (check) &#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['straddpk'] = '&#21152;&#20837;&#20027;&#32034;&#24341;&#37749;';
	$lang['strpkneedscols'] = '&#20027;&#32034;&#24341;&#37749;&#33267;&#23569;&#25033;&#21253;&#21547;&#19968;&#20491;&#36039;&#26009;&#34892;&#12290;';
	$lang['strpkadded'] = '&#25104;&#21151;&#21152;&#20837;&#20027;&#32034;&#24341;&#37749;&#12290;';
	$lang['strpkaddedbad'] = '&#21152;&#20837;&#20027;&#32034;&#24341;&#37749;&#20316;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['stradduniq'] = '&#21152;&#20837;&#29544;&#19968;&#37749;';
	$lang['struniqneedscols'] = '&#29544;&#19968;&#37749;&#33267;&#23569;&#25033;&#21253;&#21547;&#19968;&#20491;&#36039;&#26009;&#34892;&#12290;';
	$lang['struniqadded'] = '&#25104;&#21151;&#21152;&#20837;&#29544;&#19968;&#37749;&#12290;';
	$lang['struniqaddedbad'] = '&#21152;&#20837;&#29544;&#19968;&#37749;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['straddfk'] = '&#21152;&#20837;&#22806;&#37096;&#32034;&#24341;&#37749;';
	$lang['strfkneedscols'] = '&#22806;&#37096;&#32034;&#24341;&#37749;&#33267;&#23569;&#25033;&#21253;&#21547;&#19968;&#20491;&#36039;&#26009;&#34892;&#12290;';
	$lang['strfkneedstarget'] = '&#22806;&#37096;&#32034;&#24341;&#37749;&#38656;&#21443;&#29031;&#30446;&#27161;&#36039;&#26009;&#34920;&#12290;';
	$lang['strfkadded'] = '&#25104;&#21151;&#21152;&#20837;&#22806;&#37096;&#32034;&#24341;&#37749;&#12290;';
	$lang['strfkaddedbad'] = '&#21152;&#20837;&#22806;&#37096;&#32034;&#24341;&#37749;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strfktarget'] = '&#30446;&#27161;&#36039;&#26009;&#34920;';
	$lang['strfkcolumnlist'] = '&#37749;&#25152;&#21547;&#30340;&#36039;&#26009;&#34892;';
	$lang['strondelete'] = '&#26044;&#21034;&#38500;&#26178;';
	$lang['stronupdate'] = '&#26044;&#26356;&#25913;&#26178;';	

	// Functions
	$lang['strfunction'] = '&#20989;&#25976;';
	$lang['strfunctions'] = '&#20989;&#25976;';
	$lang['strshowallfunctions'] = '&#39023;&#31034;&#25152;&#26377;&#30340;&#20989;&#25976;';
	$lang['strnofunction'] = '&#25214;&#19981;&#21040;&#27492;&#20989;&#25976;&#12290;';
	$lang['strnofunctions'] = '&#25214;&#19981;&#21040;&#20219;&#20309;&#20989;&#25976;&#12290;';
	$lang['strcreatefunction'] = '&#24314;&#31435;&#26032;&#20989;&#25976;';
	$lang['strfunctionname'] = '&#20989;&#25976;&#21517;';
	$lang['strreturns'] = '&#36820;&#22238;';
	$lang['strarguments'] = '&#21443;&#25976;';
	$lang['strproglanguage'] = '&#31243;&#24335;&#35486;&#35328;';
	$lang['strfunctionneedsname'] = '&#24744;&#38656;&#28858;&#24744;&#30340;&#20989;&#25976;&#21629;&#21517;&#12290;';
	$lang['strfunctionneedsdef'] = '&#24744;&#24517;&#38920;&#23450;&#32681;&#24744;&#30340;&#20989;&#25976;&#12290;';
	$lang['strfunctioncreated'] = '&#25104;&#21151;&#24314;&#31435;&#26032;&#20989;&#25976;&#12290;';
	$lang['strfunctioncreatedbad'] = '&#26032;&#24314;&#20989;&#25976;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strconfdropfunction'] = '&#24744;&#30906;&#23450;&#35201;&#21034;&#38500;&#20989;&#25976; &quot;%s&quot;?';
	$lang['strfunctiondropped'] = '&#25104;&#21151;&#21034;&#38500;&#20989;&#25976;&#12290;';
	$lang['strfunctiondroppedbad'] = '&#21034;&#38500;&#20989;&#25976;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strfunctionupdated'] = '&#25104;&#21151;&#26356;&#25913;&#20989;&#25976;&#12290;';
	$lang['strfunctionupdatedbad'] = '&#26356;&#25913;&#20989;&#25976;&#20316;&#26989;&#22833;&#25943;&#12290;';

	// Triggers
	$lang['strtrigger'] = '&#35320;&#30332;&#22120;';
	$lang['strtriggers'] = '&#35320;&#30332;&#22120;';
	$lang['strshowalltriggers'] = '&#39023;&#31034;&#25152;&#26377;&#30340;&#35320;&#30332;&#22120;';
	$lang['strnotrigger'] = '&#25214;&#19981;&#21040;&#27492;&#35320;&#30332;&#22120;&#12290;';
	$lang['strnotriggers'] = '&#25214;&#19981;&#21040;&#20219;&#20309;&#35320;&#30332;&#22120;&#12290;';
	$lang['strcreatetrigger'] = '&#24314;&#31435;&#26032;&#35320;&#30332;&#22120;';
	$lang['strtriggerneedsname'] = '&#24744;&#38656;&#28858;&#24744;&#30340;&#35320;&#30332;&#22120;&#21629;&#21517;&#12290;';
	$lang['strtriggerneedsfunc'] = '&#24744;&#24517;&#38920;&#28858;&#20320;&#30340;&#35320;&#30332;&#22120;&#25351;&#23450;&#19968;&#20491;&#20989;&#25976;&#12290;';
	$lang['strtriggercreated'] = '&#25104;&#21151;&#24314;&#31435;&#26032;&#35320;&#30332;&#22120;&#12290;';
	$lang['strtriggercreatedbad'] = '&#24314;&#31435;&#35320;&#30332;&#22120;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strconfdroptrigger'] = '&#24744;&#30906;&#23450;&#35201;&#21034;&#38500;&#35320;&#30332;&#22120; &quot;%s&quot; &#26044; &quot;%s&quot;?';
	$lang['strtriggerdropped'] = '&#25104;&#21151;&#21034;&#38500;&#35320;&#30332;&#22120;&#12290;';
	$lang['strtriggerdroppedbad'] = '&#21034;&#38500;&#35320;&#30332;&#22120;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strtriggeraltered'] = '&#35320;&#30332;&#22120;&#24050;&#20462;&#25913;&#12290;';
	$lang['strtriggeralteredbad'] = '&#20462;&#25913;&#35320;&#30332;&#22120;&#20316;&#26989;&#22833;&#25943;&#12290;';

	// Types
	$lang['strtype'] = '&#39006;&#22411;';
	$lang['strtypes'] = '&#39006;&#22411;';
	$lang['strshowalltypes'] = '&#39023;&#31034;&#25152;&#26377;&#30340;&#39006;&#22411;';
	$lang['strnotype'] = '&#25214;&#19981;&#21040;&#27492;&#39006;&#22411;&#12290;';
	$lang['strnotypes'] = '&#25214;&#19981;&#21040;&#20219;&#20309;&#39006;&#22411;&#12290;';
	$lang['strcreatetype'] = '&#24314;&#31435;&#26032;&#39006;&#22411;';
	$lang['strtypename'] = '&#39006;&#22411;&#21517;';
	$lang['strinputfn'] = '&#36664;&#20837;&#20989;&#25976;';
	$lang['stroutputfn'] = '&#36664;&#20986;&#20989;&#25976;';
	$lang['strpassbyval'] = '&#20197;&#20540;&#20659;&#36865;?';
	$lang['stralignment'] = '&#25490;&#21015;';
	$lang['strelement'] = '&#20803;&#32032;';
	$lang['strdelimiter'] = '&#20998;&#38548;&#31526;&#34399;';
	$lang['strstorage'] = '&#20786;&#23384;';
	$lang['strtypeneedsname'] = '&#24744;&#38656;&#28858;&#24744;&#30340;&#39006;&#22411;&#21629;&#21517;&#12290;';
	$lang['strtypeneedslen'] = '&#24744;&#24517;&#38920;&#25351;&#23450;&#24744;&#30340;&#39006;&#22411;&#30340;&#38263;&#24230;&#12290;';
	$lang['strtypecreated'] = '&#25104;&#21151;&#24314;&#31435;&#26032;&#39006;&#22411;';
	$lang['strtypecreatedbad'] = ' &#24314;&#31435;&#39006;&#22411;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strconfdroptype'] = '&#24744;&#30906;&#23450;&#35201;&#21034;&#38500;&#39006;&#22411; &quot;%s&quot;?';
	$lang['strtypedropped'] = '&#25104;&#21151;&#21034;&#38500;&#39006;&#22411;&#12290;';
	$lang['strtypedroppedbad'] = '&#21034;&#38500;&#39006;&#22411;&#20316;&#26989;&#22833;&#25943;&#12290;';

	// Schemas
	$lang['strschema'] = '&#27169;&#24335;';
	$lang['strschemas'] = '&#27169;&#24335;';
	$lang['strshowallschemas'] = '&#39023;&#31034;&#25152;&#26377;&#30340;&#27169;&#24335;';
	$lang['strnoschema'] = '&#25214;&#19981;&#21040;&#27492;&#27169;&#24335;';
	$lang['strnoschemas'] = '&#25214;&#19981;&#21040;&#20219;&#20309;&#27169;&#24335;&#12290;';
	$lang['strcreateschema'] = '&#24314;&#31435;&#26032;&#27169;&#24335;';
	$lang['strschemaname'] = '&#27169;&#24335;&#21517;';
	$lang['strschemaneedsname'] = '&#24744;&#38656;&#28858;&#24744;&#30340;&#27169;&#24335;&#21629;&#21517;&#12290;';
	$lang['strschemacreated'] = '&#25104;&#21151;&#24314;&#31435;&#26032;&#27169;&#24335;&#12290;';
	$lang['strschemacreatedbad'] = '&#24314;&#31435;&#27169;&#24335;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strconfdropschema'] = '&#24744;&#30906;&#23450;&#35201;&#21034;&#38500;&#27169;&#24335; &quot;%s&quot;?';
	$lang['strschemadropped'] = '&#25104;&#21151;&#21034;&#38500;&#27169;&#24335;&#12290; ';
	$lang['strschemadroppedbad'] = '&#21034;&#38500;&#27169;&#24335;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strschemaaltered'] = '&#25104;&#21151;&#20462;&#25913;&#27169;&#24335;';
	$lang['strschemaalteredbad'] = '&#20462;&#25913;&#27169;&#24335;&#22833;&#25943;&#12290;';
	
	// Reports
	$lang['strreport'] = '&#22577;&#34920;';
	$lang['strreports'] = '&#22577;&#34920;';
	$lang['strshowallreports'] = '&#39023;&#31034;&#25152;&#26377;&#30340;&#22577;&#34920;';
	$lang['strnoreports'] = '&#25214;&#19981;&#21040;&#27492;&#22577;&#34920;&#12290;';
	$lang['strcreatereport'] = '&#24314;&#31435;&#26032;&#22577;&#34920;';
	$lang['strreportdropped'] = '&#25104;&#21151;&#21034;&#38500;&#22577;&#34920;&#12290;';
	$lang['strreportdroppedbad'] = '&#21034;&#38500;&#22577;&#34920;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strconfdropreport'] = '&#24744;&#30906;&#23450;&#35201;&#21034;&#38500;&#22577;&#34920; &quot;%s&quot;?';
	$lang['strreportneedsname'] = '&#24744;&#38656;&#28858;&#24744;&#30340;&#22577;&#34920;&#21629;&#21517;&#12290;';
	$lang['strreportneedsdef'] = '&#24744;&#38656;&#32102;&#24744;&#30340;&#22577;&#34920; SQL&#12290;';
	$lang['strreportcreated'] = '&#25104;&#21151;&#20786;&#23384;&#22577;&#34920;&#12290;';
	$lang['strreportcreatedbad'] = '&#28961;&#27861;&#20786;&#23384;&#22577;&#34920;&#12290;';
	
	// Domains
	$lang['strdomain'] = '&#38936;&#22495;';
	$lang['strdomains'] = '&#38936;&#22495;';
	$lang['strshowalldomains'] = '&#39023;&#31034;&#25152;&#26377;&#38936;&#22495;';
	$lang['strnodomains'] = '&#25214;&#19981;&#21040;&#20219;&#20309;&#38936;&#22495;&#12290;';
	$lang['strcreatedomain'] = '&#26032;&#24314;&#38936;&#22495;';
	$lang['strdomaindropped'] = '&#38936;&#22495;&#24050;&#21034;&#38500;&#12290;';
	$lang['strdomaindroppedbad'] = '&#38936;&#22495;&#21034;&#38500;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strconfdropdomain'] = '&#24744;&#30906;&#23450;&#35201;&#21034;&#38500;&#38936;&#22495; &quot;%s&quot;?';
	$lang['strdomainneedsname'] = '&#24744;&#38656;&#28858;&#27492;&#38936;&#22495;&#21629;&#21517;&#12290;';
	$lang['strdomaincreated'] = '&#38936;&#22495;&#24050;&#24314;&#31435;&#12290;';
	$lang['strdomaincreatedbad'] = '&#26032;&#24314;&#38936;&#22495;&#20316;&#26989;&#22833;&#25943;&#12290;';	
	$lang['strdomainaltered'] = '&#38936;&#22495;&#24050;&#20462;&#25913;&#12290;';
	$lang['strdomainalteredbad'] = '&#20462;&#25913;&#38936;&#22495;&#20316;&#26989;&#22833;&#25943;&#12290;';
	
	// Operators
	$lang['stroperator'] = '&#36939;&#31639;&#23376;';
	$lang['stroperators'] = '&#36939;&#31639;&#23376;';
	$lang['strshowalloperators'] = '&#39023;&#31034;&#25152;&#26377;&#36939;&#31639;&#23376;s';
	$lang['strnooperator'] = '&#25214;&#19981;&#21040;&#36939;&#31639;&#23376;&#12290;';
	$lang['strnooperators'] = '&#25214;&#19981;&#21040;&#20219;&#20309;&#36939;&#31639;&#23376;&#12290;';
	$lang['strcreateoperator'] = '&#26032;&#24314;&#36939;&#31639;&#23376;';
	$lang['strleftarg'] = '&#24038;&#24341;&#25976;&#22411;&#24907;';
	$lang['strrightarg'] = '&#21491;&#24341;&#25976;&#22411;&#24907;';
    $lang['strcommutator'] = '&#36681;&#25563;&#22120;'; 
    $lang['strnegator'] = '&#21542;&#23450;&#22120;'; 
    $lang['strrestrict'] = '&#38480;&#21046;'; 
    $lang['strjoin'] = '&#32080;&#21512;'; 
    $lang['strhashes'] = 'Hashes'; 
    $lang['strmerges'] = '&#21512;&#20341;'; 
    $lang['strleftsort'] = '&#24038;&#25490;&#24207;'; 
    $lang['strrightsort'] = '&#21491;&#25490;&#24207;'; 
    $lang['strlessthan'] = '&#23567;&#26044;'; 
    $lang['strgreaterthan'] = '&#22823;&#26044;'; 
	$lang['stroperatorneedsname'] = '&#24744;&#38656;&#28858;&#24744;&#30340;&#36939;&#31639;&#23376;&#21629;&#21517;&#12290;';
	$lang['stroperatorcreated'] = '&#36939;&#31639;&#23376;&#24050;&#24314;&#31435;';
	$lang['stroperatorcreatedbad'] = '&#36939;&#31639;&#23376;&#26032;&#24314;&#20316;&#26989;&#22833;&#25943;&#12290;';
	$lang['strconfdropoperator'] = '&#24744;&#30906;&#23450;&#35201;&#21034;&#38500;&#36939;&#31639;&#23376; &quot;%s&quot;?';
	$lang['stroperatordropped'] = '&#36939;&#31639;&#23376;&#24050;&#21034;&#38500;&#12290;';
	$lang['stroperatordroppedbad'] = '&#36939;&#31639;&#23376;&#21034;&#38500;&#22833;&#25943;&#12290;';

	// Casts 
   $lang['strcasts'] = '&#22411;&#21029;&#36681;&#25563;'; 
   $lang['strnocasts'] = '&#25214;&#19981;&#21040;&#22411;&#21029;&#36681;&#25563;&#12290;'; 
   $lang['strsourcetype'] = '&#21407;&#22987;&#22411;&#21029;'; 
   $lang['strtargettype'] = '&#30446;&#25725;&#22411;&#21029;'; 
   $lang['strimplicit'] = '&#38577;&#21547;'; 
   $lang['strinassignment'] = '&#25351;&#27966;&#20013;'; 
   $lang['strbinarycompat'] = '(&#20108;&#20803;&#30456;&#31526;)'; 

   // Conversions 
   $lang['strconversions'] = '&#36681;&#25563;'; 
   $lang['strnoconversions'] = '&#25214;&#19981;&#21040;&#36681;&#25563;&#12290;'; 
   $lang['strsourceencoding'] = '&#21407;&#22987;&#32232;&#30908;'; 
   $lang['strtargetencoding'] = '&#30446;&#27161;&#32232;&#30908;'; 

   // Languages 
   $lang['strlanguages'] = '&#35486;&#35328;'; 
   $lang['strnolanguages'] = '&#25214;&#19981;&#21040;&#35486;&#35328;&#12290;'; 
   $lang['strtrusted'] = '&#21463;&#20449;&#20219;&#30340;'; 

   // Info 
   $lang['strnoinfo'] = '&#28961;&#27861;&#21462;&#24471;&#36039;&#35338;&#12290;'; 
   $lang['strreferringtables'] = '&#21443;&#29031;&#36039;&#26009;&#34920;'; 
   $lang['strparenttables'] = '&#29238;&#36039;&#26009;&#34920;'; 
   $lang['strchildtables'] = '&#23376;&#36039;&#26009;&#34920;'; 

   // Aggregates
   $lang['straggregates'] = '&#21295;&#32317;';
   $lang['strnoaggregates'] = '&#25214;&#19981;&#21040;&#20219;&#20309;&#21295;&#32317;&#12290;';
   $lang['stralltypes'] = '(&#20840;&#37096;&#39006;&#22411;)';	
	
   // Operator Classes
   $lang['stropclasses'] = '&#36939;&#31639;&#23376;&#39006;&#21029;';
   $lang['strnoopclasses'] = '&#25214;&#19981;&#21040;&#20219;&#20309;&#36939;&#31639;&#39006;&#21029;&#12290;';
   $lang['straccessmethod'] = '&#25298;&#32085;&#23384;&#21462;';
   
   // Stats and performance
   $lang['strrowperf'] = '&#36039;&#26009;&#34892;&#25928;&#29575;';
   $lang['strioperf'] = 'I/O&#25928;&#29575;';
   $lang['stridxrowperf'] = '&#32034;&#24341;&#34892;&#25928;&#29575;';
   $lang['stridxioperf'] = '&#32034;&#24341;I/O&#25928;&#29575;';
   $lang['strpercent'] = '%';
   $lang['strsequential'] = '&#24490;&#24207;';
   $lang['strscan'] = '&#25475;&#25551;';
   $lang['strread'] = '&#35712;&#21462;';
   $lang['strfetch'] = 'Fetch';
   $lang['strheap'] = 'Heap';
   $lang['strtoast'] = 'TOAST';
   $lang['strtoastindex'] = 'TOAST&#32034;&#24341;';
   $lang['strcache'] = '&#24555;&#21462;';
   $lang['strdisk'] = '&#30913;&#30879;';
   $lang['strrows2'] = '&#36039;&#26009;&#34892;';
   
	// Miscellaneous
   $lang['strtopbar'] = '%s &#22519;&#34892;&#26044; %s:%s &#65293; &#24744;&#26159; &quot;%s&quot; , %s';
   $lang['strtimefmt'] = 'jS M, Y g:iA';
   $lang['strhelp'] = '&#35498;&#26126;';
	
?>
